Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(890)

Unified Diff: cc/tiles/tile_manager.cc

Issue 1202843008: cc: Fix BytesPerPixel issue and refactor. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Corrected comments. Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/tiles/tile_manager.cc
diff --git a/cc/tiles/tile_manager.cc b/cc/tiles/tile_manager.cc
index de3601a3dfdf696de33c20bc59711626d40e694d..a78bb3b315bb573a9952cac01551c0a3b92c165d 100644
--- a/cc/tiles/tile_manager.cc
+++ b/cc/tiles/tile_manager.cc
@@ -1025,9 +1025,9 @@ TileManager::MemoryUsage::MemoryUsage(size_t memory_bytes,
TileManager::MemoryUsage TileManager::MemoryUsage::FromConfig(
const gfx::Size& size,
ResourceFormat format) {
// We can use UncheckedMemorySizeBytes here since this is used with a tile
// size which is determined by the compositor (it's at most max texture size).
- return MemoryUsage(Resource::UncheckedMemorySizeBytes(size, format), 1);
+ return MemoryUsage(ResourceUtil::UncheckedSizeInBytes(size, format), 1);
}
// static
@@ -1025,9 +1025,9 @@ TileManager::MemoryUsage::MemoryUsage(size_t memory_bytes,
const gfx::Size& size,
ResourceFormat format) {
- // We can use UncheckedMemorySizeBytes here since this is used with a tile
+ // We can use UncheckedSizeInBytes here since this is used with a tile
// size which is determined by the compositor (it's at most max texture size).

Powered by Google App Engine
This is Rietveld 408576698